Simple library, to transform names into phonemes in the Portuguese language of Brazil.

Sample
------

```python
>>> import fonema
>>> fonema.phonectic("Sample Name")
"SN"
```


Importante
----------

Baseado no repositório https://github.com/carlosjordao/metaphone-ptbr de autoria do Carlos Costa Jordão.